==> vintasoft-web-twain-js-15.1.1.tgz: package/README.md <==
# VintaSoft TWAIN .NET SDK for Web

VintaSoft Twain .NET SDK provides JavaScript API and VintaSoft Web TWAIN service, which allow to create web application for acquiring images from TWAIN or SANE scanner in Windows and Linux.
Developed web application can be used in all major web browsers (Chrome, Firefox, Edge, Opera, Internet Explorer, etc).

## Features

  * SDK can be used for developing ASP.NET Core, ASP.NET MVC, ASP.NET WebForms, Angular, React.js, PHP or other JavaScript-based web application for Windows and Linux
  * The SDK core for Web is written in JavaScript, also TypeScript modules are available
  * Scan documents in any modern web browser (Chrome, Firefox, Edge, Internet Explorer, Opera)
  * Control image scanner, which is compatible with TWAIN specification 1.x, in Windows
  * Control image scanner, which is compatible with TWAIN specification 2.x, in Windows and Linux
  * Control a local image scanner in Linux, which is compatible with SANE API
  * Enumerate and select TWAIN/SANE scanner
  * Acquire images from TWAIN/SANE scanner
  * Process scanned images
  * Save scanned images to a file or get image file as Base64 string
  * Upload scanned images to HTTP(S)

## Online Demos

  * [VintaSoft JavaScript TWAIN Scanning Demo](https://demos.vintasoft.com/JavaScriptTwainScanningDemo/): Demonstrates how to acquire images from TWAIN/SANE scanner in JavaScript application for Windows and Linux. Scanned images can be processed, saved to a file or uploaded to HTTP(S) server.
  * [VintaSoft ASP.NET Core TWAIN Scanning Demo](https://demos.vintasoft.com/AspNetCoreTwainScanningDemo/): Demonstrates how to acquire images from TWAIN/SANE scanner in ASP.NET Core application for Windows and Linux. Scanned images can be processed, saved to a file or uploaded to HTTP(S) server.
  * [VintaSoft ASP.NET Core TWAIN Scanning Advanced Demo](https://demos.vintasoft.com/AspNetCoreTwainScanningAdvancedDemo/): Demonstrates how to acquire images from TWAIN/SANE scanner in ASP.NET Core application for Windows and Linux. Demo also allows to view/process/annotate scanned images on server, recognize barcodes in scanned images on server, upload scanned images to the server.

## Documentation

  * [Developer's Guide and API Reference](https://www.vintasoft.com/docs/vstwain-dotnet-web/?referer=npmjs.org/vintasoft-web-twain-js)

## Tutorials

  * [Acquire images from TWAIN scanner in HTML+JavaScript application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_JavaScript.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET Core application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_Core.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET Core application with React.js](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_Core_with_React.js.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET Core application with Angular](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_Core_with_Angular.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET MVC5 application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_MVC.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET WebForms application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_WebForms.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in Angular application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_Angular.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in React.js application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_React.js.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in Vue.js application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_Vue.js.html?referer=npmjs.org/vintasoft-web-twain-js)

## License Key
Please read how to get the evaluation license [here](https://www.vintasoft.com/docs/vstwain-dotnet-web/Licensing-Twain_Web-Evaluation.html?referer=npmjs.org/vintasoft-web-twain-js).

## Installation

- Official web site

    [Download installer for VintaSoft TWAIN .NET SDK](https://www.vintasoft.com/download.html?referer=npmjs.org/vintasoft-web-twain-js)

- NPM

    ```bash
    npm install vintasoft-web-twain-js
    ```

## Contact Us

[Contact VintaSoft](https://myaccount.vintasoft.com/user/submitTicket?referer=npmjs.org/vintasoft-web-twain-js)

## License Agreement
[Read license agreement](https://www.vintasoft.com/vstwain-dotnet-license.html?referer=npmjs.org/vintasoft-web-twain-js)

==> vintasoft-web-twain-js-15.2.0.tgz: package/README.md <==
# VintaSoft TWAIN .NET SDK for Web

VintaSoft Twain .NET SDK provides JavaScript API and VintaSoft Web TWAIN service, which allow to create web application for acquiring images from TWAIN/SANE/eSCL image scanner in Windows and Linux.
Developed web application can be used in all major web browsers (Chrome, Firefox, Edge, Opera, Internet Explorer, etc).

## Features

  * SDK can be used for developing ASP.NET Core, ASP.NET MVC, ASP.NET WebForms, Angular, React.js, PHP or other JavaScript-based web application for Windows and Linux
  * The SDK core for Web is written in JavaScript, also TypeScript modules are available
  * Scan documents in any modern web browser (Chrome, Firefox, Edge, Internet Explorer, Opera)
  * Control an image scanner, which is compatible with TWAIN specification 1.x, in Windows
  * Control an image scanner, which is compatible with TWAIN specification 2.x, in Windows and Linux
  * Control an image scanner, which is compatible with SANE API, in Linux
  * Control an image scanner, which is compatible with eSCL API, in Windows and Linux
  * Enumerate and select TWAIN/SANE/eSCL image scanner
  * Acquire images from TWAIN/SANE/eSCL image scanner
  * Process scanned images
  * Save scanned images to a file or get image file as Base64 string
  * Upload scanned images to HTTP(S)

## Online Demos

  * [VintaSoft JavaScript TWAIN Scanning Demo](https://demos.vintasoft.com/JavaScriptTwainScanningDemo/): Demonstrates how to acquire images from TWAIN/SANE/eSCL image scanner in JavaScript application for Windows and Linux. Scanned images can be processed, saved to a file or uploaded to HTTP(S) server.
  * [VintaSoft ASP.NET Core TWAIN Scanning Demo](https://demos.vintasoft.com/AspNetCoreTwainScanningDemo/): Demonstrates how to acquire images from TWAIN/SANE/eSCL image scanner in ASP.NET Core application for Windows and Linux. Scanned images can be processed, saved to a file or uploaded to HTTP(S) server.
  * [VintaSoft ASP.NET Core TWAIN Scanning Advanced Demo](https://demos.vintasoft.com/AspNetCoreTwainScanningAdvancedDemo/): Demonstrates how to acquire images from TWAIN/SANE/eSCL image scanner in ASP.NET Core application for Windows and Linux. Demo also allows to view/process/annotate scanned images on server, recognize barcodes in scanned images on server, upload scanned images to the server.

## Documentation

  * [Developer's Guide and API Reference](https://www.vintasoft.com/docs/vstwain-dotnet-web/?referer=npmjs.org/vintasoft-web-twain-js)

## Tutorials

  * [Acquire images from TWAIN scanner in HTML+JavaScript application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_JavaScript.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET Core application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_Core.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET Core application with React.js](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_Core_with_React.js.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET Core application with Angular](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_Core_with_Angular.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET MVC5 application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_MVC.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in ASP.NET WebForms application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_ASP.NET_WebForms.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in Angular application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_Angular.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in React.js application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_React.js.html?referer=npmjs.org/vintasoft-web-twain-js)
  * [Acquire images from TWAIN scanner in Vue.js application](https://www.vintasoft.com/docs/vstwain-dotnet-web/Programming-Twain_Web-Tutorials-Acquire_images_from_TWAIN_scanner_in_Vue.js.html?referer=npmjs.org/vintasoft-web-twain-js)

## License Key
Please read how to get the evaluation license [here](https://www.vintasoft.com/docs/vstwain-dotnet-web/Licensing-Twain_Web-Evaluation.html?referer=npmjs.org/vintasoft-web-twain-js).

## Installation

- Official web site

    [Download installer for VintaSoft TWAIN .NET SDK](https://www.vintasoft.com/download.html?referer=npmjs.org/vintasoft-web-twain-js)

- NPM

    ```bash
    npm install vintasoft-web-twain-js
    ```

## Contact Us

[Contact VintaSoft](https://myaccount.vintasoft.com/user/submitTicket?referer=npmjs.org/vintasoft-web-twain-js)

## License Agreement
[Read license agreement](https://www.vintasoft.com/vstwain-dotnet-license.html?referer=npmjs.org/vintasoft-web-twain-js)
